@@ -227,6 +227,9 @@ abbrev_long_sha <- function(x) {
 #' @export
 
 format.packages_info <- function(x, ...) {
+  if (nrow(x) == 0) {
+    return(cli::col_grey("No packages."))
+  }
 
   unloaded <- is.na(x$loadedversion)
   flib <- function(x) ifelse(is.na(x), "?", as.integer(x))
@@ -242,6 +245,7 @@ format.packages_info <- function(x, ...) {
     check.names = FALSE
   )
 
+  anyattached <- any(x$attached)
   badloaded <- package_version(x$loadedversion, strict = FALSE) !=
     package_version(x$ondiskversion, strict = FALSE)
   badloaded <- !is.na(badloaded) & badloaded
@@ -301,6 +305,10 @@ format.packages_info <- function(x, ...) {
   )
 
   if ("!" %in% names(px)) fmt <- c(fmt, "")
+  if (anyattached) {
+    fmt <- c(fmt, paste0(" ", dng("*"), " ", dash(2),
+                         " Packages attached to the search path."))
+  }
   if (any(badloaded)) {
     fmt <- c(fmt, paste0(" ", dng("V"), " ", dash(2),
                          " Loaded and on-disk version mismatch."))
