@@ -58,9 +58,6 @@ session_info <- function(
 
   if (missing(info)) info <- "auto"
   choices <- c("platform", "packages", "python", "external")
-  if (info != "auto" && info != "all") {
-    info <- match.arg(info, choices, several.ok = TRUE)
-  }
   if ("all" %in% info) {
     info <- choices
   } else if ("auto" %in% info) {
@@ -69,6 +66,8 @@ session_info <- function(
       "packages",
       if (should_show_python(pkgs)) "python"
     )
+  } else {
+    info <- match.arg(info, choices, several.ok = TRUE)
   }
 
   stopifnot(is_flag(to_file) || is_string(to_file))
@@ -115,7 +114,7 @@ format.session_info <- function(x, ...) {
         ""
       )
     },
-    if ("packages" %in% names(x)) {
+    if ("packages" %in% names(x) && nrow(x$packages) > 0) {
       c(rule("Packages"), format(x$packages), "")
     },
     if ("external" %in% names(x)) {
