@@ -1,11 +1,15 @@
 
 test_that("platform_info", {
+  withr::local_options(sessioninfo.include_hostname = FALSE)
   pi <- platform_info()
-  expect_equal(
-    names(pi),
-    c("version", "os", "system", "ui", "language", "collate", "ctype",
-      "tz", "date", "pandoc")
+  nms <- c("version", "os", "system", "hostname", "ui", "language",
+    "collate", "ctype", "tz", "date", "pandoc", "quarto"
   )
+  expect_equal(names(pi), setdiff(nms, "hostname"))
+
+  withr::local_options(sessioninfo.include_hostname = TRUE)
+  pi <- platform_info()
+  expect_equal(names(pi), nms)
 
   ## This can be a variety of strings, e.g. "R Under development"
   expect_match(pi$version, "R ")
@@ -29,3 +33,12 @@ test_that("print.platform_info ignores max.print", {
   out <- tail(strsplit(out, split = "\r?\n")[[1]], -1)
   expect_length(out, length(pi))
 })
+
+test_that("get_quarto_version", {
+  local_mocked_bindings(Sys.which = function(...) "")
+  expect_snapshot(get_quarto_version())
+
+  local_mocked_bindings(Sys.which = function(...) "/path/to/quarto")
+  local_mocked_bindings(system2 = function(...) "1.3.450")
+  expect_snapshot(get_quarto_version())
+})
